@@ -10,13 +10,14 @@
 
 using namespace Quotient;
 
+class CustomEmojiModel;
+
 /// \brief Handles user interactions with NeoChat (joining room, creating room,
 /// sending message). Account management is handled by Controller.
 class ActionsHandler : public QObject
 {
     Q_OBJECT
 
-
     /// \brief The connection that will handle sending the message.
     Q_PROPERTY(Connection *connection READ connection WRITE setConnection NOTIFY connectionChanged)
 
@@ -33,8 +34,6 @@ public:
     explicit ActionsHandler(QObject *parent = nullptr);
     ~ActionsHandler();
 
-
-
     [[nodiscard]] Connection *connection() const;
     void setConnection(Connection *connection);
 
@@ -45,7 +44,7 @@ Q_SIGNALS:
     /// \brief Show error or information message.
     ///
     /// These messages will be displayed in the room view header.
-    void showMessage(MessageType messageType, QString message);
+    void showMessage(ActionsHandler::MessageType messageType, QString message);
 
     void roomChanged();
     void connectionChanged();
@@ -55,8 +54,12 @@ public Q_SLOTS:
     /// \brief Post a message.
     ///
     /// This also interprets commands if any.
-    void
-    postMessage(const QString &text, const QString &attachementPath, const QString &replyEventId, const QString &editEventId, const QVariantMap &usernames);
+    void postMessage(const QString &text,
+                     const QString &attachementPath,
+                     const QString &replyEventId,
+                     const QString &editEventId,
+                     const QVariantMap &usernames,
+                     CustomEmojiModel *cem);
 
     /// \brief Send edit instructions (.e.g s/hallo/hello/)
     ///
