@@ -1,8 +1,5 @@
-/**
- * SPDX-FileCopyrightText: Tobias Fella <fella@posteo.de>
- *
- * SPDX-LicenseIdentifier: GPL-2.0-or-later
- */
+// SPDX-FileCopyrightText: Tobias Fella <fella@posteo.de>
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #pragma once
 
@@ -35,5 +32,6 @@ public:
     Q_INVOKABLE void setName(int index, const QString &name);
 
 private:
+    void fetchDevices();
     QVector<Quotient::Device> m_devices;
 };
