@@ -58,7 +58,6 @@ Q_SIGNALS:
     void matrixIdChanged();
     void passwordChanged();
     void deviceNameChanged();
-    void initialSyncFinished();
     void loginFlowsChanged();
     void ssoUrlChanged();
     void connected();
@@ -77,6 +76,6 @@ private:
     bool m_supportsPassword = false;
     Connection *m_connection = nullptr;
     QUrl m_ssoUrl;
-    bool m_testing;
+    bool m_testing = false;
     bool m_isLoggingIn = false;
 };
