@@ -69,7 +69,6 @@
 #include "roomlistmodel.h"
 #include "roommanager.h"
 #include "sortfilterroomlistmodel.h"
-#include "spellcheckhighlighter.h"
 #include "userdirectorylistmodel.h"
 #include "userlistmodel.h"
 #include "webshortcutmodel.h"
@@ -148,12 +147,11 @@ int main(int argc, char *argv[])
                      QStringLiteral(NEOCHAT_VERSION_STRING),
                      i18n("Matrix client"),
                      KAboutLicense::GPL_V3,
-                     i18n("© 2018-2020 Black Hat, 2020-2021 KDE Community"));
+                     i18n("© 2018-2020 Black Hat, 2020-2022 KDE Community"));
     about.addAuthor(i18n("Black Hat"), QString(), QStringLiteral("bhat@encom.eu.org"));
     about.addAuthor(i18n("Carl Schwan"), QString(), QStringLiteral("carl@carlschwan.eu"));
     about.addAuthor(i18n("Tobias Fella"), QString(), QStringLiteral("fella@posteo.de"));
     about.setOrganizationDomain("kde.org");
-    about.setBugAddress("https://invent.kde.org/network/neochat/issues");
 
     about.addComponent(QStringLiteral("libQuotient"),
                        i18n("A Qt5 library to write cross-platform clients for Matrix"),
@@ -198,7 +196,6 @@ int main(int argc, char *argv[])
     qmlRegisterSingletonInstance("org.kde.neochat", 1, 0, "AccountRegistry", &Quotient::AccountRegistry::instance());
     qmlRegisterType<ActionsHandler>("org.kde.neochat", 1, 0, "ActionsHandler");
     qmlRegisterType<ChatDocumentHandler>("org.kde.neochat", 1, 0, "ChatDocumentHandler");
-    qmlRegisterType<SpellcheckHighlighter>("org.kde.neochat", 1, 0, "SpellcheckHighlighter");
     qmlRegisterType<RoomListModel>("org.kde.neochat", 1, 0, "RoomListModel");
     qmlRegisterType<KWebShortcutModel>("org.kde.neochat", 1, 0, "WebShortcutModel");
     qmlRegisterType<UserListModel>("org.kde.neochat", 1, 0, "UserListModel");
