@@ -83,7 +83,11 @@ void NeoChatRoom::uploadFile(const QUrl &url, const QString &body)
 
     QString txnId = postFile(body.isEmpty() ? url.fileName() : body, url, false);
     setHasFileUploading(true);
+#ifdef QUOTIENT_07
+    connect(this, &Room::fileTransferCompleted, [this, txnId](const QString &id, FileSourceInfo) {
+#else
     connect(this, &Room::fileTransferCompleted, [this, txnId](const QString &id, const QUrl & /*localFile*/, const QUrl & /*mxcUrl*/) {
+#endif
         if (id == txnId) {
             setFileUploadingProgress(0);
             setHasFileUploading(false);
@@ -610,6 +614,7 @@ QString NeoChatRoom::markdownToHTML(const QString &markdown)
     result.replace(QRegularExpression("(<br />)*$"), "");
     result.replace("<p>", "");
     result.replace("</p>", "");
+    result.replace("\n", "<br>");
 
     return result;
 }
@@ -650,7 +655,6 @@ void NeoChatRoom::postMessage(const QString &rawText, const QString &text, Messa
 
 void NeoChatRoom::postHtmlMessage(const QString &text, const QString &html, MessageEventType type, const QString &replyEventId, const QString &relateToEventId)
 {
-    bool isRichText = Qt::mightBeRichText(html);
     bool isReply = !replyEventId.isEmpty();
     bool isEdit = !relateToEventId.isEmpty();
     const auto replyIt = findInTimeline(replyEventId);
@@ -696,7 +700,7 @@ void NeoChatRoom::postHtmlMessage(const QString &text, const QString &html, Mess
             "\">In reply to</a> <a href=\"https://matrix.to/#/" +
             replyEvt.senderId() + "\">" + replyEvt.senderId() +
             "</a><br>" + eventToString(replyEvt, Qt::RichText) +
-            "</blockquote></mx-reply>" + (isRichText ? html : text)
+            "</blockquote></mx-reply>" + html
           }
         };
         // clang-format on
@@ -706,11 +710,7 @@ void NeoChatRoom::postHtmlMessage(const QString &text, const QString &html, Mess
         return;
     }
 
-    if (isRichText) {
-        Room::postHtmlMessage(text, html, type);
-    } else {
-        Room::postMessage(text, type);
-    }
+    Room::postHtmlMessage(text, html, type);
 }
 
 void NeoChatRoom::toggleReaction(const QString &eventId, const QString &reaction)
