@@ -66,6 +66,12 @@ public:
     /// \see lastEvent
     [[nodiscard]] QDateTime lastActiveTime();
 
+    /// Get subtitle text for room
+    ///
+    /// Fetches last event and removes markdown formatting
+    /// \see lastEventToString
+    [[nodiscard]] QString subtitleText();
+
     bool isEventHighlighted(const Quotient::RoomEvent *e) const;
 
     [[nodiscard]] QString joinRule() const;
@@ -121,6 +127,7 @@ public:
 
     Q_INVOKABLE QString htmlSafeName() const;
     Q_INVOKABLE QString htmlSafeDisplayName() const;
+    Q_INVOKABLE void clearInvitationNotification();
 
 #ifndef QUOTIENT_07
     Q_INVOKABLE QString htmlSafeMemberName(const QString &userId) const
