@@ -20,11 +20,14 @@ public:
     static NotificationsManager &instance();
 
     Q_INVOKABLE void
-    postNotification(NeoChatRoom *room, const QString &roomName, const QString &sender, const QString &text, const QImage &icon, const QString &replyEventId);
+    postNotification(NeoChatRoom *room, const QString &sender, const QString &text, const QImage &icon, const QString &replyEventId, bool canReply);
     void postInviteNotification(NeoChatRoom *room, const QString &title, const QString &sender, const QImage &icon);
 
+    void clearInvitationNotification(const QString &roomId);
+
 private:
     NotificationsManager(QObject *parent = nullptr);
 
     QMultiMap<QString, KNotification *> m_notifications;
+    QHash<QString, QPointer<KNotification>> m_invitations;
 };
