@@ -32,7 +32,7 @@ void UserListModel::setRoom(Quotient::Room *room)
     if (m_currentRoom) {
         m_currentRoom->disconnect(this);
         //    m_currentRoom->connection()->disconnect(this);
-        for (User *user : qAsConst(m_users)) {
+        for (User *user : std::as_const(m_users)) {
             user->disconnect(this);
         }
         m_users.clear();
@@ -47,16 +47,16 @@ void UserListModel::setRoom(Quotient::Room *room)
             m_users = m_currentRoom->users();
             std::sort(m_users.begin(), m_users.end(), room->memberSorter());
         }
-        for (User *user : qAsConst(m_users)) {
+        for (User *user : std::as_const(m_users)) {
 #ifdef QUOTIENT_07
-            connect(user, &User::defaultAvatarChanged, this, [=](){
+            connect(user, &User::defaultAvatarChanged, this, [this, user]() {
                 avatarChanged(user, m_currentRoom);
             });
 #else
             connect(user, &User::avatarChanged, this, &UserListModel::avatarChanged);
 #endif
         }
-        connect(m_currentRoom->connection(), &Connection::loggedOut, this, [=] {
+        connect(m_currentRoom->connection(), &Connection::loggedOut, this, [this] {
             setRoom(nullptr);
         });
         qDebug() << m_users.count() << "user(s) in the room";
@@ -104,7 +104,7 @@ QVariant UserListModel::data(const QModelIndex &index, int role) const
             return UserType::Member;
         }
 
-        if (userPl < pl->powerLevelForState("m.room.message")) {
+        if (userPl < pl->powerLevelForEvent("m.room.message")) {
             return UserType::Muted;
         }
 
@@ -154,7 +154,7 @@ void UserListModel::userAdded(Quotient::User *user)
     m_users.insert(pos, user);
     endInsertRows();
 #ifdef QUOTIENT_07
-    connect(user, &User::defaultAvatarChanged, this, [=](){
+    connect(user, &User::defaultAvatarChanged, this, [this, user]() {
         avatarChanged(user, m_currentRoom);
     });
 #else
